
# All Properties

This page lists all [solution_name] properties including advanced and deprecated properties.
For most use cases, refer to [basic properties](basic-properties.md).


## [packagist](detectors/packagist.md)

| Property | Description |
| --- | --- |
| [detect.packagist.dependency.types.excluded](detectors/packagist.md#packagist-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, DEV </p><p>Packagist Dependency Types Excluded: Set this value to indicate which Packagist dependency types Detect should exclude from the BOM. </p>  |


## [impact\-analysis](configuration/impact-analysis.md)

| Property | Description |
| --- | --- |
| [detect.impact.analysis.enabled](configuration/impact-analysis.md#vulnerability-impact-analysis-enabled) | <p>default: false</p><p>Vulnerability Impact Analysis Enabled: If set to true, Detect will attempt to look for *.class files and generate a Vulnerability Impact Analysis Report for upload to Black Duck. </p>  |
| [detect.impact.analysis.output.path](configuration/impact-analysis.md#impact-analysis-output-directory) | <p>Impact Analysis Output Directory: The path to the output directory for Impact Analysis reports. </p>  |


## [sbt](detectors/sbt.md)

| Property | Description |
| --- | --- |
| [detect.sbt.path](detectors/sbt.md#sbt-executable) | <p>Sbt Executable: Path to the Sbt executable. </p>  |
| [detect.sbt.arguments](detectors/sbt.md#additional-sbt-command-arguments) | <p>Additional sbt command Arguments: A space-separated list of additional arguments to add to sbt command line when running Detect against an SBT project. Detect will execute the command 'sbt {additional arguments} {Detect-added arguments}'. </p>  |


## [rapid\-scan](configuration/rapid-scan.md)

| Property | Description |
| --- | --- |
| [detect.blackduck.rapid.compare.mode](configuration/rapid-scan.md#rapid-compare-mode-advanced) (Advanced)| <p>default: ALL</p> <p>Acceptable Values: ALL, BOM_COMPARE, BOM_COMPARE_STRICT </p><p>Rapid Compare Mode: Controls how rapid scan evaluates policy rules </p>  |


## [bitbake](detectors/bitbake.md)

| Property | Description |
| --- | --- |
| [detect.bitbake.build.env.name](detectors/bitbake.md#bitbake-init-script-name) | <p>default: oe-init-build-env</p><p>BitBake Init Script Name: The name of the build environment init script. </p>  |
| [detect.bitbake.package.names](detectors/bitbake.md#bitbake-package-names) | <p>BitBake Package Names: A comma-separated list of package names from which dependencies are extracted. </p>  |
| [detect.bitbake.source.arguments](detectors/bitbake.md#bitbake-source-arguments) | <p>BitBake Source Arguments: A comma-separated list of arguments to supply when sourcing the build environment init script. </p>  |
| [detect.bitbake.search.depth](detectors/bitbake.md#bitbake-search-depth) | <p>default: 1</p><p>BitBake Search Depth: The depth at which Detect will search for files generated by Bitbake. </p>  |
| [detect.bitbake.dependency.types.excluded](detectors/bitbake.md#bitbake-excluded-dependency-types) | <p>default: NONE</p> <p>Acceptable Values: NONE, BUILD </p><p>Bitbake Excluded Dependency Types: The dependency types to exclude from the results. </p>  |


## [iac\-scan](configuration/iac-scan.md)

| Property | Description |
| --- | --- |
| [detect.iac.scan.paths](configuration/iac-scan.md#iac-scan-target-paths) | <p>IaC Scan Target Paths: A comma-separated list of paths to perform IaC scans on. </p>  |
| [detect.iac.scan.arguments](configuration/iac-scan.md#iac-scan-arguments) | <p>IaC Scan Arguments: A space-separated list of additional arguments to use when running the IaC Scanner. </p>  |
| [detect.iac.scanner.local.path](configuration/iac-scan.md#iac-scanner-local-path) | <p>IaC Scanner Local Path: Use this property to specify the path to a local IaC Scanner. </p>  |


## [conan](detectors/conan.md)

| Property | Description |
| --- | --- |
| [detect.conan.path](detectors/conan.md#conan-executable) | <p>Conan Executable: The path to the conan executable. </p>  |
| [detect.conan.dependency.types.excluded](detectors/conan.md#conan-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, BUILD </p><p>Conan Dependency Types Excluded: Set this value to indicate which Conan dependency types Detect should exclude from the BOM. </p>  |
| [detect.conan.arguments](detectors/conan.md#additional-conan-arguments) | <p>Additional Conan Arguments: A space-separated list of additional arguments to add to the 'conan info' command line when running Detect against a Conan project. Detect will execute the command 'conan info {additional arguments} .' </p>  |
| [detect.conan.lockfile.path](detectors/conan.md#conan-lockfile) | <p>Conan Lockfile: The path to the conan lockfile to apply when running 'conan info' to get the dependency graph. If set, Detect will execute the command 'conan info --lockfile {lockfile} .' </p>  |
| [detect.conan.attempt.package.revision.match](detectors/conan.md#attempt-package-revision-match) | <p>default: false</p><p>Attempt Package Revision Match: If package revisions are available (a Conan lock file is found or provided, and Conan's revisions feature is enabled), require that each dependency's package revision match the package revision of the component in the KB. </p>  |


## [project](configuration/project.md)

| Property | Description |
| --- | --- |
| [detect.policy.check.fail.on.severities](configuration/project.md#fail-on-policy-violation-severities) | <p>default: NONE</p> <p>Acceptable Values: ALL, NONE, BLOCKER, CRITICAL, MAJOR, MINOR, OK, TRIVIAL, UNSPECIFIED </p><p>Fail on Policy Violation Severities: A comma-separated list of policy violation severities that will fail Detect. If this is set to NONE, Detect will not fail due to policy violations. A value of ALL is equivalent to all of the other possible values except NONE. </p>  |
| [detect.policy.check.fail.on.names](configuration/project.md#fail-on-policy-names-with-violations) | <p>Fail on Policy Names with Violations: A comma-separated list of policy names with a non-zero number of violations that will fail Detect. </p>  |
| [detect.project.description](configuration/project.md#project-description) | <p>Project Description: If project description is specified, your project will be created with this description. For updates, see detect.project.version.update. </p>  |
| [detect.project.name](configuration/project.md#project-name) | <p>Project Name: An override for the name to use for the Black Duck project. If not supplied, Detect will attempt to use the tools to figure out a reasonable project name. If that fails, the final part of the directory path where the inspection is taking place will be used. </p>  |
| [detect.project.tier](configuration/project.md#project-tier) | <p>Project Tier: If a Black Duck project tier is specified, your project will be created with this tier. For updates, see detect.project.version.update. </p>  |
| [detect.project.version.name](configuration/project.md#version-name) | <p>Version Name: An override for the version to use for the Black Duck project. If not supplied, Detect will attempt to use the tools to figure out a reasonable version name. If that fails, the current date will be used. </p>  |
| [detect.project.version.nickname](configuration/project.md#version-nickname) | <p>Version Nickname: If a project version nickname is specified, your project version will be created with this nickname. For updates, see detect.project.version.update. </p>  |
| [detect.project.version.notes](configuration/project.md#version-notes) | <p>Version Notes: If project version notes are specified, your project version will be created with these notes. For updates, see detect.project.version.update. </p>  |
| [detect.project.version.phase](configuration/project.md#version-phase) | <p>default: DEVELOPMENT</p> <p>Acceptable Values: ARCHIVED, DEPRECATED, DEVELOPMENT, PLANNING, PRERELEASE, RELEASED </p><p>Version Phase: If project version phase is specified, your project version will be created with this phase. For updates, see detect.project.version.update. </p>  |
| [detect.project.version.update](configuration/project.md#update-project-version) | <p>default: false</p><p>Update Project Version: If set to true, Detect will update the Black Duck project and project version according to configured project and project version properties. (By default, these properties are only set on created projects / project versions.) </p>  |
| [detect.project.version.license](configuration/project.md#project-version-license) | <p>Project Version License: If project version license is specified, your project version will be created with this license. For updates, see detect.project.version.update. </p>  |
| [detect.clone.project.version.name](configuration/project.md#clone-project-version-name-advanced) (Advanced)| <p>Clone Project Version Name: The name of the project version to clone this project version from. Respects the given Clone Categories in detect.project.clone.categories or as set on the Black Duck server. </p>  |
| [detect.clone.project.version.latest](configuration/project.md#clone-latest-project-version-advanced) (Advanced)| <p>default: false</p><p>Clone Latest Project Version: If set to true, detect will attempt to use the latest project version as the clone for this project. The project must exist and have at least one version. </p>  |
| [detect.code.location.name](configuration/project.md#scan-name-advanced) (Advanced)| <p>Scan Name: An override for the base name Detect will use for the scan (codelocation) it creates. Detect appends a suffix to the base name that indicates the source ("scan" for the signature scanner, "gradle/bom" for the Gradle detector, etc.). If this property is set and multiple code locations are generated from the same source, Detect will also append an index to avoid name collisions. When this property is set, detect.project.codelocation.prefix and detect.project.codelocation.suffix are ignored. </p>  |
| [detect.project.application.id](configuration/project.md#application-id-advanced) (Advanced)| <p>Application ID: Sets the 'Application ID' project setting. </p>  |
| [detect.project.group.name](configuration/project.md#project-group-name-advanced) (Advanced)| <p>Project Group Name: Sets the 'Project Group' to assign the project to. Must match exactly to an existing project group on Black Duck. </p>  |
| [detect.custom.fields.project](configuration/project.md#custom-fields-advanced) (Advanced)| <p>Custom Fields: A  list of custom fields with a label and comma-separated value starting from index 0. For each index, provide one label and one value. For example, to set a custom field with label 'example' to 'one,two': `detect.custom.fields.project[0].label='example'` and `detect.custom.fields.project[0].value='one,two'`. To set another field, use index 1. Note that these will not show up in the detect configuration log. </p>  |
| [detect.custom.fields.version](configuration/project.md#custom-fields-advanced) (Advanced)| <p>Custom Fields: A  list of custom fields with a label and comma-separated value starting from index 0. For each index, provide one label and one value. For example , to set a custom field with label 'example' to 'one,two': `detect.custom.fields.version[0].label='example'` and `detect.custom.fields.version[0].value='one,two'`. To set another field, use index 1. Note that these will not show up in the detect configuration log. </p>  |
| [detect.project.clone.categories](configuration/project.md#clone-project-categories-advanced) (Advanced)| <p>default: ALL</p> <p>Acceptable Values: ALL, NONE, COMPONENT_DATA, CUSTOM_FIELD_DATA, DEEP_LICENSE, LICENSE_TERM_FULFILLMENT, VERSION_SETTINGS, VULN_DATA </p><p>Clone Project Categories: The value of this property is used to set the 'Cloning' settings on created Black Duck projects. If property detect.project.version.update is set to true, the value of this property is used to set the 'Cloning' settings on updated Black Duck projects. </p>  |
| [detect.project.codelocation.prefix](configuration/project.md#scan-name-prefix-advanced) (Advanced)| <p>Scan Name Prefix: A prefix to the name of the scans created by Detect. Useful for running against the same projects on multiple machines. </p>  |
| [detect.project.codelocation.suffix](configuration/project.md#scan-name-suffix-advanced) (Advanced)| <p>Scan Name Suffix: A suffix to the name of the scans created by Detect. </p>  |
| [detect.project.codelocation.unmap](configuration/project.md#unmap-all-other-scans-for-project-advanced) (Advanced)| <p>default: false</p><p>Unmap All Other Scans for Project: If set to true, unmaps all other scans mapped to the project version produced by the current run of Detect. </p>  |
| [detect.project.user.groups](configuration/project.md#project-user-groups-advanced) (Advanced)| <p>Project User Groups: A comma-separated list of names of user groups to add to the project. </p>  |
| [detect.project.tags](configuration/project.md#project-tags-advanced) (Advanced)| <p>Project Tags: A comma-separated list of tags to add to the project. This property is not supported when using Synopsys Detect in offline mode. </p>  |
| [detect.project.level.adjustments](configuration/project.md#allow-project-level-adjustments-advanced) (Advanced)| <p>default: true</p><p>Allow Project Level Adjustments: If set, created projects will be created with the value of this property. For updates, see detect.project.version.update. </p>  |
| [detect.parent.project.name](configuration/project.md#parent-project-name-advanced) (Advanced)| <p>Parent Project Name: When a parent project and version name are specified, the created detect project will be added as a component to the specified parent project version. The specified parent project and parent project version must exist on Black Duck. </p>  |
| [detect.parent.project.version.name](configuration/project.md#parent-project-version-name-advanced) (Advanced)| <p>Parent Project Version Name: When a parent project and version name are specified, the created detect project will be added as a component to the specified parent project version. The specified parent project and parent project version must exist on Black Duck. </p>  |
| [detect.project.version.distribution](configuration/project.md#version-distribution-advanced) (Advanced)| <p>default: EXTERNAL</p> <p>Acceptable Values: EXTERNAL, INTERNAL, OPENSOURCE, SAAS </p><p>Version Distribution: If project version distribution is specified, your project version will be created with this distribution. For updates, see detect.project.version.update. </p>  |


## [project\-inspector](configuration/project-inspector.md)

| Property | Description |
| --- | --- |
| [detect.project.inspector.path](configuration/project-inspector.md#project-inspector-path-advanced) (Advanced)| <p>Project Inspector Path: Use this property to point Detect to a local Project Inspector zip file, instead of the default Project Inspector zip file that Detect downloads from the binary repository. You need to ensure the version is compatible (the same major version that Detect downloads by default). </p>  |
| [detect.project.inspector.arguments](configuration/project-inspector.md#project-inspector-additional-arguments-advanced) (Advanced)| <p>Project Inspector Additional Arguments: A space-separated list of additional options to pass to all invocations of the project inspector. </p>  |


## [pnpm](detectors/pnpm.md)

| Property | Description |
| --- | --- |
| [detect.pnpm.dependency.types.excluded](detectors/pnpm.md#pnpm-dependency-types) | <p>default: NONE</p> <p>Acceptable Values: NONE, DEV, OPTIONAL </p><p>pnpm Dependency Types: Set this value to indicate which pnpm dependency types Detect should exclude from the BOM. </p>  |


## [docker](detectors/docker.md)

| Property | Description |
| --- | --- |
| [detect.docker.image](detectors/docker.md#docker-image-name) | <p>Docker Image Name: The Docker image name (repo:tag) to inspect. </p>  |
| [detect.docker.image.id](detectors/docker.md#docker-image-id) | <p>Docker Image ID: The ID (shown in the 'IMAGE ID' column of 'docker images' output) of the target Docker image. The target image must already be local (must appear in the output of 'docker images'). </p>  |
| [detect.docker.path](detectors/docker.md#docker-executable) | <p>Docker Executable: Path to the docker executable (used to load image inspector Docker images in order to run the Docker Inspector in air gap mode). </p>  |
| [detect.docker.tar](detectors/docker.md#image-archive-file) | <p>Image Archive File: An image .tar file which is either a Docker image saved to a file using the 'docker save' command, or an Open Container Initiative (OCI) image .tar file. The file must be readable by all. </p>  |
| [detect.docker.passthrough](detectors/docker.md#docker-passthrough-advanced) (Advanced)| <p>Docker Passthrough: Additional properties may be passed to the docker inspector by adding the prefix detect.docker.passthrough to each Docker Inspector property name and assigning a value. The 'detect.docker.passthrough' prefix will be removed from the property name to generate the property name passed to Docker Inspector (with the given value). </p>  |
| [detect.docker.inspector.path](detectors/docker.md#docker-inspector-path-advanced) (Advanced)| <p>Docker Inspector Path: Use this property to point Detect to a local Docker Inspector jar file, instead of the default Docker Inspector jar file that Detect downloads from the binary repository. You need to ensure the version is compatible (the same major version that Detect downloads by default). </p>  |
| [detect.docker.inspector.version](detectors/docker.md#docker-inspector-version-advanced) (Advanced)| <p>Docker Inspector Version: Version of the Docker Inspector to use. By default Detect will attempt to automatically determine the version to use. </p>  |
| [detect.docker.platform.top.layer.id](detectors/docker.md#platform-top-layer-id-advanced) (Advanced)| <p>Platform Top Layer ID: To exclude components from platform layers from the results, assign to this property the ID of the top layer of the platform image. Get the platform top layer ID from the output of 'docker inspect platformimage:tag'. The platform top layer ID is the last item in RootFS.Layers. For more information, see 'Isolating application components' in the Docker Inspector documentation. </p>  |


## [bazel](detectors/bazel.md)

| Property | Description |
| --- | --- |
| [detect.bazel.path](detectors/bazel.md#bazel-executable) | <p>Bazel Executable: The path to the Bazel executable. </p>  |
| [detect.bazel.target](detectors/bazel.md#bazel-target) | <p>Bazel Target: The Bazel target (for example, //foo:foolib) for which dependencies are collected. For Detect to run Bazel, this property must be set. </p>  |
| [detect.bazel.cquery.options](detectors/bazel.md#bazel-cquery-additional-options) | <p>Bazel cquery additional options: A comma-separated list of additional options to pass to the bazel cquery command. </p>  |
| [detect.bazel.workspace.rules](detectors/bazel.md#bazel-workspace-rules) | <p>default: NONE</p> <p>Acceptable Values: ALL, NONE, MAVEN_JAR, MAVEN_INSTALL, HASKELL_CABAL_LIBRARY, HTTP_ARCHIVE </p><p>Bazel workspace rules: By default Detect discovers Bazel dependencies using all of the supported Bazel workspace rules that it finds in the WORKSPACE file. Alternatively you can use this property to specify the list of Bazel workspace rules Detect should use. </p>  |


## [dart](detectors/dart.md)

| Property | Description |
| --- | --- |
| [detect.dart.path](detectors/dart.md#dart-executable) | <p>dart Executable: The path to the dart executable. </p>  |
| [detect.flutter.path](detectors/dart.md#flutter-executable) | <p>flutter Executable: The path to the flutter executable. </p>  |
| [detect.pub.dependency.types.excluded](detectors/dart.md#dart-pub-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, DEV </p><p>Dart Pub Dependency Types Excluded: Set this value to indicate which Dart pub dependency types Detect should exclude from the BOM. </p>  |


## [general](configuration/general.md)

| Property | Description |
| --- | --- |
| [detect.target.type](configuration/general.md#detect-target) | <p>default: SOURCE</p> <p>Acceptable Values: SOURCE, IMAGE </p><p>Detect Target: Informs detect of what is being scanned which allows improved user experience when scanning different types of targets. </p>  |
| [detect.wait.for.results](configuration/general.md#wait-for-results) | <p>default: false</p><p>Wait For Results: If set to true, Detect will wait for Synopsys products until results are available or the detect.timeout is exceeded. </p>  |
| [detect.follow.symbolic.links](configuration/general.md#follow-symbolic-links) | <p>default: true</p><p>Follow Symbolic Links: If set to true, Detect will follow symbolic links when searching for detectors, when searching for files that select detectors (such as Bitbake and Sbt) need, when searching for directories to exclude from signature scan, and when searching for binary scan targets.  Symbolic links are not supported for Impact Analysis. </p>  |
| [detect.parallel.processors](configuration/general.md#detect-parallel-processors-advanced) (Advanced)| <p>default: 1</p><p>Detect Parallel Processors: The number of threads to run processes in parallel, defaults to 1, but if you specify less than or equal to 0, the number of processors on the machine will be used. </p>  |
| [detect.ignore.connection.failures](configuration/general.md#detect-ignore-connection-failures-advanced) (Advanced)| <p>default: false</p><p>Detect Ignore Connection Failures: If true, Detect will ignore any products (eg. Black Duck) that it cannot connect to. </p>  |
| [detect.force.success](configuration/general.md#force-success-advanced) (Advanced)| <p>default: false</p><p>Force Success: If true, Detect will always exit with code 0. </p>  |
| [detect.force.success.on.skip](configuration/general.md#force-success-on-skip-advanced) (Advanced)| <p>default: false</p><p>Force Success On Skip: If true, Detect will always exit with code 0 when a scan of any type is skipped. Typically this happens when the Black Duck minimum scan interval timer has not been met. </p>  |


## [pear](detectors/pear.md)

| Property | Description |
| --- | --- |
| [detect.pear.dependency.types.excluded](detectors/pear.md#pear-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, OPTIONAL </p><p>Pear Dependency Types Excluded: Set this value to indicate which Pear dependency types Detect should exclude from the BOM. </p>  |
| [detect.pear.path](detectors/pear.md#pear-executable) | <p>Pear Executable: The path to the pear executable. </p>  |


## [default](configuration/default.md)

| Property | Description |
| --- | --- |
| [detect.phone.home.passthrough](configuration/default.md#phone-home-passthrough-advanced) (Advanced)| <p>Phone Home Passthrough: Additional values may be sent home for usage information. The keys will be sent without the prefix. </p>  |


## [pip](detectors/pip.md)

| Property | Description |
| --- | --- |
| [detect.pipfile.dependency.types.excluded](detectors/pip.md#pipfile-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, DEV </p><p>Pipfile Dependency Types Excluded: A comma-separated list of dependency types that will be excluded. </p>  |
| [detect.pip.project.name](detectors/pip.md#pip-project-name) | <p>PIP Project Name: The name of your PIP project, to be used if your project's name cannot be correctly inferred from its setup.py file. </p>  |
| [detect.pip.project.version.name](detectors/pip.md#pip-project-version-name) | <p>PIP Project Version Name: The version of your PIP project, to be used if your project's version name cannot be correctly inferred from its setup.py file. </p>  |
| [detect.pip.requirements.path](detectors/pip.md#pip-requirements-path) | <p>PIP Requirements Path: A comma-separated list of paths to requirements files, to be used to analyze requirements files with a filename other than requirements.txt or to specify which requirements files should be analyzed. </p>  |
| [detect.pip.only.project.tree](detectors/pip.md#pip-include-only-project-tree) | <p>default: false</p><p>PIP Include Only Project Tree: By default, pipenv includes all dependencies found in the graph. Set to true to only include dependencies found underneath the dependency that matches the provided pip project and version name. </p>  |
| [detect.pip.path](detectors/pip.md#pip-executable) | <p>Pip Executable: The path to the Pip executable. </p>  |
| [detect.pipenv.path](detectors/pip.md#pipenv-executable) | <p>Pipenv Executable: The path to the Pipenv executable. </p>  |


## [conda](detectors/conda.md)

| Property | Description |
| --- | --- |
| [detect.conda.environment.name](detectors/conda.md#anaconda-environment-name) | <p>Anaconda Environment Name: The name of the anaconda environment used by your project. </p>  |
| [detect.conda.path](detectors/conda.md#conda-executable) | <p>Conda Executable: The path to the conda executable. </p>  |


## [binary\-scanner](configuration/binary-scanner.md)

| Property | Description |
| --- | --- |
| [detect.binary.scan.file.path](configuration/binary-scanner.md#binary-scan-target) | <p>Binary Scan Target: If specified, this file and this file only will be uploaded for binary scan analysis. This property takes precedence over detect.binary.scan.file.name.patterns. The BINARY_SCAN tool does not provide project and version name defaults to Detect, so you need to set project and version names via properties when only the BINARY_SCAN tool is invoked. </p>  |
| [detect.binary.scan.file.name.patterns](configuration/binary-scanner.md#binary-scan-filename-patterns) | <p>Binary Scan Filename Patterns: If specified, files in the source directory whose names match these file name patterns will be zipped and uploaded for binary scan analysis. This property will not be used if detect.binary.scan.file.path is specified. Search depth is controlled by property detect.binary.scan.search.depth. Directories specified via property detect.excluded.directories are excluded from the file search. This property accepts filename globbing-style wildcards. Refer to the <i>Configuring Synopsys Detect</i> > <i>Property wildcard support</i> page for more details. </p>  |
| [detect.binary.scan.search.depth](configuration/binary-scanner.md#binary-scan-search-depth) | <p>default: 0</p><p>Binary Scan Search Depth: When binary scan filename patterns are being used to search for binary files to scan, this property sets the depth at which Detect will search for files (that match those patterns) to upload for binary scan analysis. </p>  |


## [hex](detectors/hex.md)

| Property | Description |
| --- | --- |
| [detect.hex.rebar3.path](detectors/hex.md#rebar3-executable) | <p>Rebar3 Executable: The path to the rebar3 executable. </p>  |


## [swift](detectors/swift.md)

| Property | Description |
| --- | --- |
| [detect.swift.path](detectors/swift.md#swift-executable) | <p>Swift Executable: Path of the swift executable. </p>  |


## [python](detectors/python.md)

| Property | Description |
| --- | --- |
| [detect.python.path](detectors/python.md#python-executable) | <p>Python Executable: The path to the Python executable. </p>  |


## [debug](configuration/debug.md)

| Property | Description |
| --- | --- |
| [detect.diagnostic](configuration/debug.md#diagnostic-mode) | <p>default: false</p><p>Diagnostic Mode: When enabled, diagnostic mode collects files valuable for troubleshooting (logs, BDIO file, extraction files, reports, etc.), writes them to a zip file, and logs the path to the zip file. </p>  |
| [detect.diagnostic.extended](configuration/debug.md#diagnostic-mode-extended-deprecated) (Deprecated)| <p>default: false</p><p>Diagnostic Mode Extended: When enabled, Synopsys Detect performs the actions of --detect.diagnostic, but also includes relevant files such as lock files and build artifacts. </p> <p>**DEPRECATED: This property is being removed. Use property detect.diagnostic instead. There is no longer any distinction between extended and non-extended diagnostic zip files. This property will be removed in 9.0.0.**</p> |


## [maven](detectors/maven.md)

| Property | Description |
| --- | --- |
| [detect.maven.build.command](detectors/maven.md#maven-build-command) | <p>Maven Build Command: Maven command line arguments to add to the mvn/mvnw command line. </p>  |
| [detect.maven.path](detectors/maven.md#maven-executable) | <p>Maven Executable: The path to the Maven executable (mvn or mvnw). </p>  |
| [detect.maven.included.scopes](detectors/maven.md#dependency-scope-included) | <p>Dependency Scope Included: A comma separated list of Maven scopes. Output will be limited to dependencies within these scopes (overridden by exclude). </p>  |
| [detect.maven.excluded.scopes](detectors/maven.md#dependency-scope-excluded) | <p>Dependency Scope Excluded: A comma separated list of Maven scopes. Output will be limited to dependencies outside these scopes (overrides include). </p>  |
| [detect.maven.excluded.modules](detectors/maven.md#maven-modules-excluded-advanced) (Advanced)| <p>Maven Modules Excluded: A comma-separated list of Maven modules (subprojects) to exclude. </p>  |
| [detect.maven.included.modules](detectors/maven.md#maven-modules-included-advanced) (Advanced)| <p>Maven Modules Included: A comma-separated list of Maven modules (subprojects) to include. </p>  |


## [go](detectors/go.md)

| Property | Description |
| --- | --- |
| [detect.go.path](detectors/go.md#go-executable) | <p>Go Executable: Path to the Go executable. </p>  |
| [detect.go.mod.dependency.types.excluded](detectors/go.md#go-mod-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, UNUSED, VENDORED </p><p>Go Mod Dependency Types Excluded: Set this value to indicate which Go Mod dependency types Detect should exclude from the BOM. </p>  |


## [npm](detectors/npm.md)

| Property | Description |
| --- | --- |
| [detect.npm.arguments](detectors/npm.md#additional-npm-command-arguments) | <p>Additional NPM Command Arguments: A space-separated list of additional arguments that Detect will add at then end of the npm ls command line when Detect executes the NPM CLI Detector on an NPM project. </p>  |
| [detect.npm.dependency.types.excluded](detectors/npm.md#npm-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, DEV, PEER </p><p>Npm Dependency Types Excluded: Set this value to indicate which Npm dependency types Detect should exclude from the BOM. </p>  |
| [detect.npm.path](detectors/npm.md#npm-executable) | <p>NPM Executable: The path to the Npm executable. </p>  |


## [blackduck\-server](configuration/blackduck-server.md)

| Property | Description |
| --- | --- |
| [blackduck.api.token](configuration/blackduck-server.md#black-duck-api-token) | <p>Black Duck API Token: The access token used to authenticate with the Black Duck Server. </p>  |
| [blackduck.offline.mode](configuration/blackduck-server.md#offline-mode) | <p>default: false</p><p>Offline Mode: This can disable any Black Duck communication - if true, Detect will not upload BDIO files, it will not check policies, and it will not download and install the signature scanner. </p>  |
| [blackduck.url](configuration/blackduck-server.md#black-duck-url) | <p>Black Duck URL: URL of the Black Duck server. </p>  |
| [detect.test.connection](configuration/blackduck-server.md#test-connection-to-black-duck) | <p>default: false</p><p>Test Connection to Black Duck: Test the connection to Black Duck with the current configuration. </p>  |
| [blackduck.trust.cert](configuration/blackduck-server.md#trust-all-ssl-certificates-advanced) (Advanced)| <p>default: false</p><p>Trust All SSL Certificates: If true, automatically trust the certificate for the current run of Detect only. </p>  |
| [detect.timeout](configuration/blackduck-server.md#detect-timeout-advanced) (Advanced)| <p>default: 300</p><p>Detect Timeout: The amount of time in seconds Detect will wait for network connection, for scans to finish, and to generate reports (i.e. risk and policy check). When changing this value, keep in mind the checking of policies might have to wait for scans to process which can take some time. </p>  |
| [detect.blackduck.scan.mode](configuration/blackduck-server.md#detect-scan-mode-advanced) (Advanced)| <p>default: INTELLIGENT</p> <p>Acceptable Values: RAPID, EPHEMERAL, INTELLIGENT </p><p>Detect Scan Mode: Set the Black Duck scanning mode of Detect </p>  |


## [nuget](detectors/nuget.md)

| Property | Description |
| --- | --- |
| [detect.nuget.config.path](detectors/nuget.md#nuget-config-file) | <p>Nuget Config File: The path to the Nuget.Config file to supply to the nuget exe. </p>  |
| [detect.nuget.packages.repo.url](detectors/nuget.md#nuget-packages-repository-url) | <p>default: https://api.nuget.org/v3/index.json</p><p>Nuget Packages Repository URL: The source for nuget packages </p>  |
| [detect.nuget.excluded.modules](detectors/nuget.md#nuget-projects-excluded-advanced) (Advanced)| <p>Nuget Projects Excluded: The projects within the solution to exclude. Detect will exclude all projects with names that include any of the given regex patterns. To match a full project name (for example: 'BaGet.Core'), use a regular expression that matches only the full name ('^BaGet.Core$') </p>  |
| [detect.nuget.ignore.failure](detectors/nuget.md#ignore-nuget-failures-advanced) (Advanced)| <p>default: false</p><p>Ignore Nuget Failures: If true errors will be logged and then ignored. </p>  |
| [detect.nuget.included.modules](detectors/nuget.md#nuget-modules-included-advanced) (Advanced)| <p>Nuget Modules Included: The names of the projects in a solution to include (overrides exclude). Detect will include all projects with names that include any of the given regex patterns. To match a full project name (for example: 'BaGet.Core'), use a regular expression that matches only the full name ('^BaGet.Core$') </p>  |


## [lerna](detectors/lerna.md)

| Property | Description |
| --- | --- |
| [detect.lerna.path](detectors/lerna.md#lerna-executable) | <p>Lerna Executable: Path of the lerna executable. </p>  |
| [detect.lerna.package.types.excluded](detectors/lerna.md#lerna-package-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, PRIVATE </p><p>Lerna Package Types Excluded: Set this value to indicate which Lerna package types Detect should exclude from the BOM. </p>  |
| [detect.lerna.excluded.packages](detectors/lerna.md#lerna-packages-excluded-advanced) (Advanced)| <p>Lerna Packages Excluded: A comma-separated list of Lerna packages to exclude. </p>  |
| [detect.lerna.included.packages](detectors/lerna.md#lerna-packages-included-advanced) (Advanced)| <p>Lerna Packages Included: A comma-separated list of Lerna packages to include. </p>  |


## [ruby](detectors/ruby.md)

| Property | Description |
| --- | --- |
| [detect.ruby.dependency.types.excluded](detectors/ruby.md#ruby-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, RUNTIME, DEV </p><p>Ruby Dependency Types Excluded: Set this value to indicate which Ruby(Gempsec) dependency types Detect should exclude from the BOM. </p>  |


## [gradle](detectors/gradle.md)

| Property | Description |
| --- | --- |
| [detect.gradle.build.command](detectors/gradle.md#gradle-build-command) | <p>Gradle Build Command: Gradle command line arguments to add to the gradle/gradlew command line. </p>  |
| [detect.gradle.configuration.types.excluded](detectors/gradle.md#gradle-configuration-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, UNRESOLVED </p><p>Gradle Configuration Types Excluded: Set this value to indicate which Gradle configuration types Detect should exclude from the BOM. </p>  |
| [detect.gradle.path](detectors/gradle.md#gradle-executable) | <p>Gradle Executable: The path to the Gradle executable (gradle or gradlew). </p>  |
| [detect.gradle.excluded.configurations](detectors/gradle.md#gradle-exclude-configurations-advanced) (Advanced)| <p>Gradle Exclude Configurations: A comma-separated list of Gradle configurations to exclude. </p>  |
| [detect.gradle.excluded.projects](detectors/gradle.md#gradle-exclude-projects-advanced) (Advanced)| <p>Gradle Exclude Projects: A comma-separated list of Gradle subprojects to exclude. </p>  |
| [detect.gradle.excluded.project.paths](detectors/gradle.md#gradle-exclude-subproject-paths-advanced) (Advanced)| <p>Gradle Exclude Subproject Paths: A comma-separated list of Gradle subproject paths to exclude. </p>  |
| [detect.gradle.included.configurations](detectors/gradle.md#gradle-include-configurations-advanced) (Advanced)| <p>Gradle Include Configurations: A comma-separated list of Gradle configurations to include. </p>  |
| [detect.gradle.included.projects](detectors/gradle.md#gradle-include-projects-advanced) (Advanced)| <p>Gradle Include Projects: A comma-separated list of Gradle subprojects to include. </p>  |
| [detect.gradle.included.project.paths](detectors/gradle.md#gradle-include-project-paths-advanced) (Advanced)| <p>Gradle Include Project Paths: A comma-separated list of Gradle subproject paths to include. </p>  |


## [proxy](configuration/proxy.md)

| Property | Description |
| --- | --- |
| [blackduck.proxy.host](configuration/proxy.md#proxy-host-advanced) (Advanced)| <p>Proxy Host: Hostname for proxy server. </p>  |
| [blackduck.proxy.ignored.hosts](configuration/proxy.md#bypass-proxy-hosts-advanced) (Advanced)| <p>Bypass Proxy Hosts: A comma separated list of regular expression host patterns that should not use the proxy. </p>  |
| [blackduck.proxy.ntlm.domain](configuration/proxy.md#ntlm-proxy-domain-advanced) (Advanced)| <p>NTLM Proxy Domain: NTLM Proxy domain. </p>  |
| [blackduck.proxy.ntlm.workstation](configuration/proxy.md#ntlm-proxy-workstation-advanced) (Advanced)| <p>NTLM Proxy Workstation: NTLM Proxy workstation. </p>  |
| [blackduck.proxy.password](configuration/proxy.md#proxy-password-advanced) (Advanced)| <p>Proxy Password: Proxy password. </p>  |
| [blackduck.proxy.port](configuration/proxy.md#proxy-port-advanced) (Advanced)| <p>Proxy Port: Proxy port. </p>  |
| [blackduck.proxy.username](configuration/proxy.md#proxy-username-advanced) (Advanced)| <p>Proxy Username: Proxy username. </p>  |


## [cpan](detectors/cpan.md)

| Property | Description |
| --- | --- |
| [detect.cpan.path](detectors/cpan.md#cpan-executable) | <p>cpan Executable: The path to the cpan executable. </p>  |
| [detect.cpanm.path](detectors/cpan.md#cpanm-executable) | <p>cpanm Executable: The path to the cpanm executable. </p>  |


## [cleanup](configuration/cleanup.md)

| Property | Description |
| --- | --- |
| [detect.cleanup](configuration/cleanup.md#cleanup-output) | <p>default: true</p><p>Cleanup Output: If true, the files created by Detect will be cleaned up. </p>  |


## [paths](configuration/paths.md)

| Property | Description |
| --- | --- |
| [detect.bash.path](configuration/paths.md#bash-executable) | <p>Bash Executable: Path to the Bash executable. </p>  |
| [detect.bdio.output.path](configuration/paths.md#bdio-output-directory) | <p>BDIO Output Directory: The path to the output directory for the generated BDIO file. </p>  |
| [detect.bdio.file.name](configuration/paths.md#bdio-file-name) | <p>BDIO File Name: The desired file name of BDIO file Detect produces in the BDIO Output Directory. </p>  |
| [detect.detector.search.depth](configuration/paths.md#detector-search-depth) | <p>default: 0</p><p>Detector Search Depth: Depth of subdirectories within the source directory to which Detect will search for files that indicate whether a detector applies. </p>  |
| [detect.git.path](configuration/paths.md#git-executable) | <p>Git Executable: Path of the git executable </p>  |
| [detect.java.path](configuration/paths.md#java-executable) | <p>Java Executable: Path to the java executable. </p>  |
| [detect.output.path](configuration/paths.md#detect-output-path) | <p>Detect Output Path: The path to the output directory. </p>  |
| [detect.scan.output.path](configuration/paths.md#scan-output-path) | <p>Scan Output Path: The output directory for all signature scanner output files. If not set, the signature scanner output files will be in a 'scan' subdirectory of the output directory. </p>  |
| [detect.source.path](configuration/paths.md#source-path) | <p>Source Path: The source path is the path to the project directory to inspect. If no value is provided, the source path defaults to the current working directory. </p>  |
| [detect.tools.excluded](configuration/paths.md#detect-tools-excluded) |  <p>Acceptable Values: NONE, DETECTOR, SIGNATURE_SCAN, BINARY_SCAN, IMPACT_ANALYSIS, DOCKER, BAZEL, IAC_SCAN </p><p>Detect Tools Excluded: The tools Detect should not allow, in a comma-separated list. Excluded tools will not be run even if all criteria for the tool is met. Exclusion rules always win. </p>  |
| [detect.tools](configuration/paths.md#detect-tools-included) |  <p>Acceptable Values: ALL, DETECTOR, SIGNATURE_SCAN, BINARY_SCAN, IMPACT_ANALYSIS, DOCKER, BAZEL, IAC_SCAN </p><p>Detect Tools Included: The tools Detect should allow in a comma-separated list. Tools in this list (as long as they are not also in the excluded list) will be allowed to run if all criteria of the tool are met. Exclusion rules always win. </p>  |
| [detect.status.json.output.path](configuration/paths.md#status-json-output-path) | <p>Status JSON Output Path: The directory to place a copy of the status.json file. </p>  |
| [detect.detector.search.continue](configuration/paths.md#detector-search-continue-advanced) (Advanced)| <p>default: false</p><p>Detector Search Continue: By default, nesting rules limit which detectors can run on a subdirectory based on which detectors applied on any parent directory. Setting this property to true disables nesting rules. </p>  |
| [detect.excluded.directories](configuration/paths.md#detect-excluded-directories-advanced) (Advanced)| <p>Detect Excluded Directories: A comma-separated list of names, name patterns, relative paths, or path patterns of directories that Detect should exclude. </p>  |
| [detect.excluded.directories.defaults.disabled](configuration/paths.md#detect-excluded-directories-defaults-disabled-advanced) (Advanced)| <p>default: false</p><p>Detect Excluded Directories Defaults Disabled: If false, Detect will exclude the default directory names. See the detailed help for more information. </p>  |
| [detect.tools.output.path](configuration/paths.md#detect-tools-output-path-advanced) (Advanced)| <p>Detect Tools Output Path: The path to the tools directory where detect should download and/or access things like the Signature Scanner that it shares over multiple runs. </p>  |
| [detect.project.detector](configuration/paths.md#project-name-and-version-detector-advanced) (Advanced)| <p>Project Name and Version Detector: The detector that will be used to determine the project name and version when multiple detector types apply. This property should be used with detect.project.tool. </p>  |
| [detect.project.tool](configuration/paths.md#detector-tool-priority-advanced) (Advanced)| <p>default: DOCKER,DETECTOR,BAZEL</p> <p>Acceptable Values: DETECTOR, SIGNATURE_SCAN, BINARY_SCAN, IMPACT_ANALYSIS, DOCKER, BAZEL, IAC_SCAN </p><p>Detector Tool Priority: The tool priority for project name and version. The project name and version will be determined by the first tool in this list that provides them. </p>  |


## [report](configuration/report.md)

| Property | Description |
| --- | --- |
| [detect.notices.report](configuration/report.md#generate-notices-report) | <p>default: false</p><p>Generate Notices Report: When set to true, a Black Duck notices report in text form will be created in your source directory. </p>  |
| [detect.notices.report.path](configuration/report.md#notices-report-path) | <p>Notices Report Path: The output directory for notices report. Default is the source directory. </p>  |
| [detect.risk.report.pdf](configuration/report.md#generate-risk-report-40pdf41) | <p>default: false</p><p>Generate Risk Report (PDF): When set to true, a Black Duck risk report in PDF form will be created. </p>  |
| [detect.risk.report.pdf.path](configuration/report.md#risk-report-output-path) | <p>Risk Report Output Path: The output directory for risk report in PDF. Default is the source directory. </p>  |


## [signature\-scanner](configuration/signature-scanner.md)

| Property | Description |
| --- | --- |
| [detect.blackduck.signature.scanner.arguments](configuration/signature-scanner.md#signature-scanner-arguments) | <p>Signature Scanner Arguments: A space-separated list of additional arguments to use when running the Black Duck signature scanner. </p>  |
| [detect.blackduck.signature.scanner.copyright.search](configuration/signature-scanner.md#signature-scanner-copyright-search) | <p>default: false</p><p>Signature Scanner Copyright Search: When set to true, user will be able to scan and discover copyright names in Black Duck. Corresponding Signature Scanner CLI Argument: --copyright-search. </p>  |
| [detect.blackduck.signature.scanner.dry.run](configuration/signature-scanner.md#signature-scanner-dry-run) | <p>default: false</p><p>Signature Scanner Dry Run: If set to true, the signature scanner results are not uploaded to Black Duck, and the scanner results are written to disk via the Signature Scanner CLI argument: --dryRunWriteDir. </p>  |
| [detect.blackduck.signature.scanner.individual.file.matching](configuration/signature-scanner.md#individual-file-matching) | <p>default: NONE</p> <p>Acceptable Values: NONE, SOURCE, BINARY, ALL </p><p>Individual File Matching: Users may set this property to indicate what types of files they want to match. Corresponding Signature Scanner CLI Argument: --individualFileMatching. </p>  |
| [detect.blackduck.signature.scanner.license.search](configuration/signature-scanner.md#signature-scanner-license-search) | <p>default: false</p><p>Signature Scanner License Search: When set to true, user will be able to scan and discover license names in Black Duck. Corresponding Signature Scanner CLI Argument: --license-search. </p>  |
| [detect.blackduck.signature.scanner.local.path](configuration/signature-scanner.md#signature-scanner-local-path) | <p>Signature Scanner Local Path: To use a local signature scanner, specify the path where the signature scanner was unzipped. This will likely look similar to 'scan.cli-x.y.z' and includes the 'bin, icon, jre, and lib' directories of the expanded scan.cli. </p>  |
| [detect.blackduck.signature.scanner.paths](configuration/signature-scanner.md#signature-scanner-target-paths) | <p>Signature Scanner Target Paths: If this property is not set, the signature scanner target path is the source path (see property detect.source.path). If this property is set, the paths provided in this property's value will be signature scanned instead (the signature scanner will be executed once for each provided path). </p>  |
| [detect.blackduck.signature.scanner.snippet.matching](configuration/signature-scanner.md#snippet-matching) | <p>default: NONE</p> <p>Acceptable Values: NONE, SNIPPET_MATCHING, SNIPPET_MATCHING_ONLY, FULL_SNIPPET_MATCHING, FULL_SNIPPET_MATCHING_ONLY </p><p>Snippet Matching: Use this value to enable the various snippet scanning modes. For a full explanation, please refer to the 'Running a component scan using the Signature Scanner command line' section in your Black Duck server's online help. Corresponding Signature Scanner CLI Arguments: --snippet-matching, --snippet-matching-only, --full-snippet-scan. </p>  |
| [detect.blackduck.signature.scanner.upload.source.mode](configuration/signature-scanner.md#upload-source-mode) | <p>default: false</p><p>Upload source mode: If set to true, the signature scanner will, if supported by your Black Duck version, upload source code to Black Duck. Corresponding Signature Scanner CLI Argument: --upload-source. </p>  |
| [detect.excluded.directories.search.depth](configuration/signature-scanner.md#detect-excluded-directories-search-depth) | <p>default: 4</p><p>Detect Excluded Directories Search Depth: Enables you to adjust the depth to which Detect will search when creating signature scanner exclusion patterns. </p>  |
| [detect.blackduck.signature.scanner.memory](configuration/signature-scanner.md#signature-scanner-memory-advanced) (Advanced)| <p>default: 4096</p><p>Signature Scanner Memory: The memory for the scanner to use. </p>  |


## [logging](configuration/logging.md)

| Property | Description |
| --- | --- |
| [logging.level.com.synopsys.integration](configuration/logging.md#logging-level) | <p>default: INFO</p> <p>Acceptable Values: OFF, ERROR, WARN, INFO, DEBUG, TRACE </p><p>Logging Level: The logging level of Detect. </p>  |
| [logging.level.detect](configuration/logging.md#logging-level-shorthand) | <p>default: INFO</p> <p>Acceptable Values: OFF, ERROR, WARN, INFO, DEBUG, TRACE </p><p>Logging Level Shorthand: Shorthand for the logging level of detect. Equivalent to setting <i>logging.level.com.synopsys.integration</i>. </p>  |


## [yarn](detectors/yarn.md)

| Property | Description |
| --- | --- |
| [detect.yarn.dependency.types.excluded](detectors/yarn.md#yarn-dependency-types-excluded) | <p>default: NONE</p> <p>Acceptable Values: NONE, NON_PRODUCTION </p><p>Yarn Dependency Types Excluded: Set this value to indicate which Yarn dependency types Detect should exclude from the BOM. </p>  |
| [detect.yarn.excluded.workspaces](detectors/yarn.md#yarn-exclude-workspaces-advanced) (Advanced)| <p>Yarn Exclude Workspaces: A comma-separated list of Yarn workspaces (specified by the workspace directory's relative path) to exclude. </p>  |
| [detect.yarn.included.workspaces](detectors/yarn.md#yarn-include-workspaces-advanced) (Advanced)| <p>Yarn Include Workspaces: A comma-separated list of Yarn workspaces (specified by the workspace directory's relative path) to include. </p>  |


## [detector](configuration/detector.md)

| Property | Description |
| --- | --- |
| [detect.required.detector.types](configuration/detector.md#required-detect-types) |  <p>Acceptable Values: BITBAKE, CARGO, CARTHAGE, COCOAPODS, CONAN, CONDA, CPAN, CRAN, DART, GIT, GO_MOD, GO_DEP, GO_VNDR, GO_VENDOR, GO_GRADLE, GRADLE, HEX, IVY, LERNA, MAVEN, NPM, NUGET, PACKAGIST, PEAR, PIP, PNPM, POETRY, RUBYGEMS, SBT, SWIFT, YARN, CLANG, XCODE </p><p>Required Detect Types: The set of required detectors. </p>  |
| [detect.accuracy.required](configuration/detector.md#detector-accuracy-requirements-advanced) (Advanced)| <p>default: ALL</p> <p>Acceptable Values: ALL, NONE, BITBAKE, CARGO, CARTHAGE, COCOAPODS, CONAN, CONDA, CPAN, CRAN, DART, GIT, GO_MOD, GO_DEP, GO_VNDR, GO_VENDOR, GO_GRADLE, GRADLE, HEX, IVY, LERNA, MAVEN, NPM, NUGET, PACKAGIST, PEAR, PIP, PNPM, POETRY, RUBYGEMS, SBT, SWIFT, YARN, CLANG, XCODE </p><p>Detector Accuracy Requirements: Detector types from which HIGH accuracy results are required when a detector of that type applies. </p>  |
| [detect.excluded.detector.types](configuration/detector.md#detector-types-excluded-advanced) (Advanced)| <p>default: NONE</p> <p>Acceptable Values: NONE, BITBAKE, CARGO, CARTHAGE, COCOAPODS, CONAN, CONDA, CPAN, CRAN, DART, GIT, GO_MOD, GO_DEP, GO_VNDR, GO_VENDOR, GO_GRADLE, GRADLE, HEX, IVY, LERNA, MAVEN, NPM, NUGET, PACKAGIST, PEAR, PIP, PNPM, POETRY, RUBYGEMS, SBT, SWIFT, YARN, CLANG, XCODE </p><p>Detector Types Excluded: By default, all detectors will be included. If you want to exclude specific detectors, specify the ones to exclude here. Exclusion rules always win. </p>  |
| [detect.included.detector.types](configuration/detector.md#detector-types-included-advanced) (Advanced)| <p>default: ALL</p> <p>Acceptable Values: ALL, BITBAKE, CARGO, CARTHAGE, COCOAPODS, CONAN, CONDA, CPAN, CRAN, DART, GIT, GO_MOD, GO_DEP, GO_VNDR, GO_VENDOR, GO_GRADLE, GRADLE, HEX, IVY, LERNA, MAVEN, NPM, NUGET, PACKAGIST, PEAR, PIP, PNPM, POETRY, RUBYGEMS, SBT, SWIFT, YARN, CLANG, XCODE </p><p>Detector Types Included: By default, all tools will be included. If you want to include only specific tools, specify the ones to include here. Exclusion rules always win. </p>  |


Documentation version: 8\.2\.0
